===============
glance-registry
===============

--------------------------------------
Server for the Glance Registry Service
--------------------------------------

.. include:: header.txt

.. include:: ../deprecate-registry.inc


SYNOPSIS
========

::

  glance-registry [options]

DESCRIPTION
===========

glance-registry is a server daemon that serves image metadata through a
REST-like API.

OPTIONS
=======

**General options**

.. include:: general_options.txt

FILES
=====

**/etc/glance/glance-registry.conf**
      Default configuration file for Glance Registry

.. include:: footer.txt
